@@ -77,12 +77,15 @@ static Bool FBDevScreenInit(int Index, ScreenPtr pScreen, int argc,
 static Bool FBDevEnterVT(int scrnIndex, int flags);
 static void FBDevLeaveVT(int scrnIndex, int flags);
 static Bool FBDevCloseScreen(int scrnIndex, ScreenPtr pScreen);
-static int fbdev_randr12_preinit(ScrnInfoPtr screen);
+static int fbdev_randr12_preinit(ScrnInfoPtr pScrn);
+static void fbdev_randr12_uninit(ScrnInfoPtr pScrn);
 static void fbdev_enable_fb_access(int scrn_index, Bool enable);
 static void fbdev_property_callback(CallbackListPtr * pcbl, pointer unused,
 				    pointer calldata);
 static int fbdev_crtc_rotate(xf86CrtcPtr crtc, int rotation);
 
+static int fbdev_crtc_rotate(xf86CrtcPtr crtc, int rotation);
+
 /* -------------------------------------------------------------------- */
 
 _X_EXPORT DriverRec FBDEV = {
@@ -542,11 +545,11 @@ static Bool FBDevCloseScreen(int scrnIndex, ScreenPtr pScreen)
 	ScrnInfoPtr pScrn = xf86Screens[scrnIndex];
 	FBDevPtr fPtr = FBDEVPTR(pScrn);
 
-        /* Rotate back to landscape to prevent Nokia logo from being
-         * messed up if shutdown from portrait mode. Do this before
-         * EXA_Fini on purpose, because pixmap hash table is released
-         * there but used on rotation. */
+	/* Rotate back to landscape to prevent Nokia logo from being messed up
+	 * if shutdown from portrait mode. Do this before EXA_Fini on purpose,
+	 * because pixmap hash table is released there but used on rotation. */
 	fbdev_crtc_rotate (fPtr->crtc_lcd, RR_Rotate_0);
+	//fbdev_randr12_uninit (pScrn);
 
 	EXA_Fini(pScreen);
 
@@ -1069,11 +1072,11 @@ bail:
 	return 0;
 }
 
-static void fbdev_randr12_uninit(ScreenPtr pScreen)
+static void fbdev_randr12_uninit(ScrnInfoPtr pScrn)
 {
-	ScrnInfoPtr pScrn = xf86Screens[pScreen->myNum];
 	FBDevPtr fPtr = FBDEVPTR(pScrn);
 
+	fbdev_crtc_rotate(fPtr->crtc_lcd, 0);
 	if (fPtr->output_lcd)
 		xf86OutputDestroy(fPtr->output_lcd);
 	fPtr->output_lcd = NULL;
